#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"              X 1 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 1 X               ",
"              <  X3X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X1X3X X<               ",
"              O a k h g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g h k g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g k j g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g h f O               ",
"              ; k.7 =.P.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.P.=.5 Z.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.J.s / I.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.K.y.                  ",
"              4 7Xh P.SXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXSXP.f zXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXBXG u.DXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXCX%X@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXzXbXmXmXmXmXmXmXmXmXmXnXxXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlX4Xl.O.#.#.#.#.#.#.#.+.r.&XkXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXzX.XZ                   p T.jXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXzX%X} 9 r r r r t , o   k !.jXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXqXT.h.l.l.l.k.h.Z #   C @XkXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXkXjXhXhXhXhXgX-XZ   : =.lXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXw.8   S ).zXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXgXsXdXdXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjX2Xm . & 2.gXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXxX#.p h s Q fXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpXa.4   D ~.vXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXcXJ       s dXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkX,Xn + # q.uXzXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXcXP       h dXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXxXyXc.-   V /.nXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXcXG       p sXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXzX%XC + @ u.wXxXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXxX8.G P J #.gXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXxXuXM.# . x [.bXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXxXcXcXcXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXcXXXJ o # i.9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXzXsXv.# O g +XzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXbX{.T   = e.wXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXzXfXu.+   s $XjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXgX'.u.f.H.dXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXvXMXMXnXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              4 7Xh P.SXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXSXP.f zXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXBXG u.DXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXCX%X#                 ",
"              ; k.0 ;.P.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.P.;.9 A.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.J.g _ P.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.K.u.O                 ",
"              O u # 9 f d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d f 9 # s d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d * 3 f d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d d f t .                 ",
"              3 -Xf A.zXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXzXA.s yXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXgXS 0.xXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXjX}.@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.NXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXOX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXnXmXmXmXbXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXbXmXmXmXnXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXjX/.K.P.J.}.zXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXzX}.J.P.K./.jXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXdXd       L cXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXcXL       d dXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXdXh       P cXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXcXP       h dXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXdXh       P cXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXcXP       h dXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXdXd       L cXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXcXL       d dXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXjX/.K.P.J.}.zXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXzX}.J.P.K./.jXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXnXmXmXmXbXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXbXmXmXmXnXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xg G.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXG.d dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 3Xh J.BXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXBXJ.d gXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXbXF t.VXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXmX@X@                 ",
"              @ N * z Y P P P P P P P P P P P P P P P P P P P P P P P P P P P P P P P P Y z * S D D D D D D D D D D D D D D D D D D D D D D D D D D D D D D D D D F , t H D D D D D D D D D D D D D D D D D D D D D D D D D D D D D D D D G b X                 ",
"              * ,.6                                                                         5 0.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.t.t J i.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.y.%.o                 ",
"              4 8Xl                                                                         j xXNXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXVXH i.FXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXZX&X#                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXcXMXMXMXMXMXMXMXMXMXcXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXgX,Xk.a.s.s.s.s.s.a.f.=XgXzXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXzXiXS.%                 V.iXzXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXxXrXl.-   ; 4 4 4 4 4 9 L.aXzXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXxXqX0.=   ( p.d.s.s.s.f.-XgXzXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXxX7X*.&   V.pXeXeXeXtXiXhXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXzXcXcXcXcXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXcX3X' % : u.w.S b ! z.tXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXbX}.L P P L }.bXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXcX,XK @ & y 3     # i =.6XcXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXmXJ.        J.mXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXcX>XF X   9 E X.A @   4 N.tXxXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXmXP.        P.mXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXxXeXb.=.] f.XX1XY.~ X . W #XvXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXmXK.        K.mXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXzXnXbXuXjXcXcXkX~.: X q /.nXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXnX/.d h h d /.nXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXgXrXrXpXjXlXlXvX*Xi o - E.mXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXjXdXdXdXdXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXkX4Xl.k.J.8XxXlXcX+Xe o 5 ~.nXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXcXoX6 ; p R.kXkXwXz.# X M |.bXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXcX:XS O X B r.D.3.t . o q.7XcXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXzXpXL.t   O 8 a 5   X I OXjXzXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXyXN.W 9     @ s O.).sXxXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXzXkX{.j.1.-.7.N.;XzXzXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXcXbXmXmXnXbXxXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              3 1Xk                                                                         h dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXD e.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXoX@                 ",
"              4 5Xl                                                                         h jXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXmXG y.ZXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXBX#X@                 ",
"              , T.i                                                                         u }.OXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX@Xb %.&XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX#XS.+                 ",
"              . @ .                                                                         . @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ X o # @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ +                   ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                "
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"                                                                                                                                                                                                ",
"      . O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O .       ",
"    X                                                                                                                                                                                     X     ",
"  X   f 0.-.2.1.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.1.2.>.>.2.1.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.1.2.>.,.2.1.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.1.,.9.p   X   ",
"  X   f C.d.0.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.9.k.h.0.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.9.l.g.0.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.6.Z.N   o   ",
"  X   m p w 8.#.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.#.9.6 i 8.$.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.#.9.3 s 7.$.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.#.7.q   @     ",
"  O   r.x.8.UXLXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXKXUX>.s.UXLXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXKXUX&.j.UXPXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXKXUXr.  +     ",
"  O   ,.0.$.LXiXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXiXIX| 2.KXpXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXiXIX' 7.JXpXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXuXGX-.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXjXhXhXhXhXhXhXhXjXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXzXZXGXFXFXFXFXFXGXCXzXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXkXzXdX].P.T.Y.T.Y.U.J.[.fXzXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXjXcX5X8               l 8XvXjXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXkXxXeX..j N m M v 3   L wXcXjXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXhX3X=X;X-X2XI.o   =.BXhXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXgXfXfXgXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXzXnXMXmXNXnX:.  t XXVXhXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXkXDXHXJXSXjXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXjXjXjXcX&XX   #.SXfXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXhXZXP u t W SXgXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXzXcX..  q @XmXhXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXgXFX6     t JXfXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXcX;XO   o.FXfXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXgXFX8     u HXfXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXjXMX`   5 ;XcXjXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXgXAXD 8 6 P DXgXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXkXxX&X%   O.SXgXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXkXAXFXFXZXkXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXgXCX/   < 1XzXkXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXgXgXgXhXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXjXnX%X6   $.BXjXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXkXhXmXA   O 4XzXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXkXkXT.M.!.cXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXDXJXAXkXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXhXgXhXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   ,.0.$.KXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXuXPX| 1.JXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXuXIX' 6.JXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXuXGX-.  +     ",
"  O   y.l.5.UXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUX-.p.UXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUX$.h.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXq.  @     ",
"  X   k v f =.| ..............................................| -.a l =.| ..............................................| -.i x =. ...............................................| *.j   X     ",
"  X   N S b i.2.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.1.p.l V u.2.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.1.p.j Z u.2.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.1.y.m   o     ",
"  O   r.k.4.UXKXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXJXUX=.u.UXLXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXJXUX@.f.UXLXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXJXUX0.  @     ",
"  O   ,.0.$.LXpXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXiXIX| 2.LXpXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXiXUX] 7.KXpXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXiXHX-.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXgXfXfXgXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXgXfXfXgXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXkXAXGXGXSXkXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXkXSXGXGXAXkXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXgXDXY q e H AXgXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXgXAXH e q Y DXgXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXfXJXy     7 FXgXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXgXFX7     y JXfXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXfXJXy     7 FXgXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXgXFX7     y JXfXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXgXDXY q e H AXgXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXgXAXH e q Y DXgXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXkXAXGXGXSXkXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXkXSXGXGXAXkXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXgXfXfXgXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXgXfXfXgXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   2.e.&.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX..4.UXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   ,.9.$.KXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXuXPX| 1.JXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXuXPX' 6.HXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXyXFX-.  +     ",
"  O   y.z.2.UXGXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXFXUX&.p.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUX$.h.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXq.  @     ",
"  X   h j m t.<.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.<.y.x f #.] [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ ' $.y l @.] [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ ' +.f   X     ",
"  X   M ~                                                           R a.7.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.6.h.l D f.7.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.6.d.B   o     ",
"  O   7.I.  - + @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ + -   A.UXKXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXHXUX@.f.UXKXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXHXUX0.  @     ",
"  O   *.n.  @                                                   @   h.DXpXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXiXUX] 7.KXpXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXiXHX-.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXhXgXgXgXgXgXgXhXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXzXAXJXGXHXHXGXJXZXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXhX~.N.G.F.F.H.C.`.kXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXjXxX9Xr             h hXkXkXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXjXbX*Xk   c D Z D n 3.kXkXkXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXgXgXgXgXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXhXNX].r   /.zXhXdX8X9XlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXkXAXFXFXAXkXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXgXCXU.1   Q.>.F } {.AXhXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXgXSXH 7 7 H SXgXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXgXDXm.o O ;       : n.AXgXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXfXGXe     e GXfXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXgXAXS.3   Y T.j.3   g ;XbXjXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXfXGXq     q GXfXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXxXcX4XhXbXNXL.  o c.FXfXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXgXAXY y y Y AXgXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXkXjXgXzXkXgXMX,X:   r.KXfXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXkXDXJXJXDXkXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXjXNXA.' w.kXNXSX#XX   g.HXfXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXgXfXfXgXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXdXKX>.    z.0X;X'   6 '.BXhXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXjXvX1Xx   + D v     >.bXjXkXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXhXNX.XW %     w 9.yXcXjXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXzXhXVXyX[.W.~.$XxXbXjXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXhXcXZXDXDXBXlXjXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXkXhXhXhXjXkXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   -.N.  @                                                   @   k.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX[ 9.UXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXIX:.  +     ",
"  O   *.b.  @                                                   @   g.AXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXyXPX' 6.HXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXyXFX-.  +     ",
"  O   6.I.  #                                                   #   A.UXHXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXFXUX+.d.UXHXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXFXUX9.  @     ",
"  X   c P   o                                                   o   G 7.-.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.-.q.f B 0.-.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.-.9.v   X     ",
"    X     o                                                       X                                                                                                                     X       ",
"      X o                                                           o @ + + + + + + + + + + + + + + + + + + + + + + + + + @ X o @ + + + + + + + + + + + + + + + + + + + + + + + + + @ X         ",
"                                                                                                                                                                                                ",
"                                                                                                                                                                                                "
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"                                                                                                                                                                                ",
"      O @ + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +         ",
"    X                                                                                                                                                                   .       ",
"  O   r.XXQ.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.!.(./.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~./.(.!.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.~.!._.H.  .     ",
"  .   f z N B B B B B B B B B B B B B B B B B B B B B B N C l b V B B B B B B B B B B B B B B B B B B B B B B V b l C N B B B B B B B B B B B B B B B B B B B B B B V p         ",
"  +   R.l rXdXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXtXKXP B.CXpXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXpXCXB.P KXtXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXgX#         ",
"  +   ^.V dXxXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXfXUX~ H.HXjXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXjXHXH.~ UXfXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXvX,   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXgXdXfXfXfXfXdXfXkXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXxXGXPXLXLXLXLXPXHXcXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXkXzXiXz.6.q.0.0.0.5.j.tXxXkXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXjXcX4X-             > :XbXjXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXkXxXuXp.*.,.;.6.b   j qXxXjXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXhXgXgXjXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXcXcXxXvXaXg   :.SXgXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXjXAXHXJXBXjXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXfXDXu.  6 6XcXkXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXjXmXE.n.c. XMXjXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXjXvX9Xk   3.VXjXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXfXLXs     { UXdXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXhXCXg.  4 7XcXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXfXJXB     &.PXdXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXkXnX7Xk   q.bXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXgXGXU * o 3.KXfXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXkXnXc.  0 <XmXjXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXvXnXnXcXkXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXcXyXi   9.MXjXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXkXMXj.  w -XNXhXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXkXzXaXu   3.AXfXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXjXuXiXhXzXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXvXvXzXkXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   E.M yXfXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXyXKXW A.CXaXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXaXCXA.W KXyXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXhX>   .     ",
"  @   $XD JXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXKXUX] ).UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX).] UXKXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX<   .     ",
"  X   C 1 E ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! W ] 8 m _ Q ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! Q _ m 8 ] W ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ~ +         ",
"  o   6.a Z.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.A.).m ;.W.D.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.D.W.;.m ).A.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.J.*         ",
"  @    XA VXHXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXCXUX_ W.UXSXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXSXUXW._ UXCXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXLX,   .     ",
"  +   Q.N pXjXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXaXUXQ D.SXfXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXfXSXD.Q UXaXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXjXzX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXxXbXbXvXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXcXbXbXcXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXzXfXwXeXtXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXzXuXeXwXaXzXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXgXHXM.    < bXkXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXfXJXM     %.PXdXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXgXGXV.  O 5 bXkXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXfXJXZ     =.PXdXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXgXJXx.    o nXkXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXfXKXg      .UXdXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXkXvX0X_.[..XzXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXkXvX$X'._.<XbXkXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXkXvXAXCXVXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXkXNXZXZXmXkXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXkXjXjXjXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXjXjXjXkXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   ~.B sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdXUX! G.GXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   Q.N pXjXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXaXUXQ D.SXfXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXfXSXD.Q UXaXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXjXzX>   .     ",
"  @   .XA nXAXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXmXUX( Q.UXSXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXSXUXW._ UXCXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXLX,   .     ",
"  o   5.s ^.`._._._._._._._._._._._._._._._._._._._._._.^.-XS =.Q.D.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.D.W.;.m ).A.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.J.*         ",
"  X   A =                                                     S ( Q ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! Q _ m 8 ] W ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ~ +         ",
"  @   -Xk   @ + + + + + + + + + + + + + + + + + + + + + + &   -XUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX).] UXKXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX<   .     ",
"  +   ^.s   .                                             +   ^.mXaXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXaXCXA.W KXyXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXhX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXkXhXjXjXjXjXhXkXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXmXZXZXZXZXZXAXvXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXcXe.< t 0 0 w > U.nXkXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXkXzXhX_   o X . +   G.mXkXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXfXfXfXkXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXkXcXiXR   i.>X*X#X^.9XxXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXzXJXJXKXvXkXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXkXbXqXm   E.Z.>.n.kXMXjXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXcXuXM Z g $XNXjXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXkXmX2X6   5       Z 0XbXkXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXbXeX      '.ZXjXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXkXnX6XB $ U W.u.-   3.cXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXkXbXwX      _.ZXjXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXxXVXpXlXnXSX8.  s fXxXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXcXaX%.=. .<XmXkXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXzXsX3XrXhXsXFXD.  1 dXcXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXzXPXPXUXbXkXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXkXNX+Xq B <XAXSX6.  z gXxXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXdXdXdXkXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXkXmX1X<   Z F.0.&   i.vXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXjXMXU.2         / iXcXkXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXjXBX=X1.~ { C.kXcXkXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXjXvXFXLXJXVXlXkXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXjXgXfXfXhXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   _.d   .                                             +   _.ZXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXGXG.! UXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX>   .     ",
"  +   '.d   .                                             +   ].FXzXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXzXLXJ.~ UXhXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXnX>   .     ",
"      = o                                                     = , > > > > > > > > > > > > > > > > > > > > > > , * + < > > > > > > > > > > > > > > > > > > > > > > > > .         ",
"                                                                                                                                                                                ",
"                                                                . . . . . . . . . . . . . . . . . . . . . . . .     . . . . . . . . . . . . . . . . . . . . . . . . .           ",
"                                                                                                                                                                                ",
"                                                                                                                                                                                "
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"                                                                                                                                ",
"        . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .         ",
"                                                                                                                                ",
"      X q e e e e e e e e e e e e e e e e e w w e e e e e e e e e e e e e e e e e w e e e e e e e e e e e e e e e e e q .       ",
"      + 2.8.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.7.8.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.6.9.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.7.3.@       ",
"  .   7 ) h.@X`.].].].].].].].].].].].].`.@Xf.| *X).].].].].].].].].].].].].].{.^.L .X`.].].].].].].].].].].].].].).*XL   O     ",
"  .   r e.+XUXVXZXZXZXZXZXZXZXZXZXZXZXZXVXUXXXh.UXMXZXZXZXZXZXZXZXZXZXZXZXZXCXSXvX:.JXVXZXZXZXZXZXZXZXZXZXZXZXZXZXMXUX-.  O     ",
"  .   w 4.`.VXgXjXjXjXjXjXjXjXjXjXjXjXjXgXVX(.y.FXdXjXjXjXhXfXfXfXfXfXjXjXjXjXlXiX#.bXgXjXjXjXjXjXjXjXjXjXjXjXjXjXdXGX+.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXkXmXDXSXSXSXZXxXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXkXcX>XK.Y.U.U.~.aXxXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXhXCXe.          -XnXjXlXxXpX#.mXjXlXlXlXlXlXhXfXjXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXxX9X.XOXOX0 a hXzXkXlXxXpX#.mXjXlXlXlXlXlXSXKXMXkXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXvXnXKXR.  n.AXhXlXlXxXpX#.mXjXlXlXlXlXxXZ.w.@XMXjXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXkXjXlXd w jXzXkXlXlXxXpX#.mXjXlXlXlXkXnX>   w.KXfXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXhXZXH.  m.AXhXlXlXlXxXpX#.mXjXlXlXlXkXbXY > Z.SXhXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXkXzXbXj e jXzXkXlXlXlXxXpX#.mXjXlXlXlXlXlXbXnXxXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXhXCXb.  M.AXhXlXlXlXlXxXpX#.mXjXlXlXlXlXlXkXkXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXkXnX=.W fXxXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXkXVXSXzXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXjXgXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   w 4.`.VXgXjXjXjXjXjXjXjXjXjXjXjXjXgXVX(.y.FXdXjXjXjXjXjXjXjXjXjXjXjXjXjXlXiX#.bXgXjXjXjXjXjXjXjXjXjXjXjXjXjXdXGX+.  O     ",
"  .   r w.+XUXVXZXZXZXZXZXZXZXZXZXZXZXZXVXUXXXg.UXNXZXZXZXZXZXZXZXZXZXZXZXZXZXDXvX-.KXVXZXZXZXZXZXZXZXZXZXZXZXZXZXNXUX*.  O     ",
"  .   5 [ j..X(._._._._._._._._._._._._.(.XXg.+.@X^._._._._._._._._._._._._.).`.Q.W {.(._._._._._._._._._._._._._.^.@XE   o     ",
"      , G @.g.y.u.u.u.u.u.u.u.u.u.u.u.u.y.g.+.I k.r.u.u.u.u.u.u.u.u.u.u.u.u.u.i.w.N s.y.u.u.u.u.u.u.u.u.u.u.u.u.u.r.k.M   X     ",
"  .   t t.&XUXFXHXHXHXHXHXHXHXHXHXHXHXHXFXUX@Xk.UXSXHXHXHXHXHXHXHXHXHXHXHXHXHXLXBX>.UXGXHXHXHXHXHXHXHXHXHXHXHXHXHXSXUX;.  O     ",
"  .   w 3._.MXdXgXgXgXgXgXgXgXgXgXgXgXgXdXNX^.r.SXaXgXgXgXgXgXgXgXgXgXgXgXgXgXjXyX@.cXdXgXgXgXgXgXgXgXgXgXgXgXgXgXaXSXO.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXkXjXjXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXjXjXkXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXkXvXBXmXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXmXBXvXkXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXkXcXeX#X,XzXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXzX,X#XeXcXkXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXgXHXd.  i nXkXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXkXnXi   d.HXgXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXgXHXd.  i nXkXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXkXnXi   d.HXgXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXkXcXeX#X,XzXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXzX,X#XeXcXkXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXkXvXBXmXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXmXBXvXkXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXkXjXjXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXjXjXkXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].ZXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX_.u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJX@.  O     ",
"  .   e 5.].CXjXlXlXlXlXlXlXlXlXlXlXlXlXjXZX).u.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXlXlXlXlXlXlXlXlXlXfXHX@.  O     ",
"  .   e 6.'.VXhXkXkXkXkXkXkXkXkXkXkXkXkXhXCX(.i.LXjXxXxXxXxXxXxXxXxXxXxXxXxXxXvXdX$.NXlXxXxXxXxXxXxXxXxXxXxXxXxXxXjXLX#.  O     ",
"  .   w 1. XGXvXnXnXnXnXnXnXnXnXnXnXnXnXvXHX{.w.BXyXpXpXpXpXpXpXpXpXpXpXpXpXpXdXqXO.jXiXpXpXpXpXpXpXpXpXpXpXpXpXpXtXBXX.  O     ",
"      - b 5 a u u u u u u u u u u u u u u a 3 B :.@.#.#.#.#.#.#.#.#.#.#.#.#.#.$.O.h &.#.#.#.#.#.#.#.#.#.#.#.#.#.#.+.>.g   X     ",
"  .   e t.                                    k.UXcXmXmXmXmXmXmXmXmXmXmXmXmXmXNXjX&.AXbXmXmXmXmXmXmXmXmXmXmXmXmXmXxXUX%.  O     ",
"  .   q 0.  @ X X X X X X X X X X X X X X @   s.DXdXjXjXjXjXjXjXjXjXjXjXjXjXjXlXiX#.bXhXjXjXjXjXjXjXjXjXjXjXjXjXjXdXGX+.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXkXgXgXgXgXjXlXlXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXkXcXSXGXGXJXCXkXlXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXkXbX>XL n b a 3.mXjXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXlXkXkXlXlXlXlXlXlXxXpX#.mXjXlXjXBX!.  M { F 9.mXkXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXzXnXnXzXlXlXlXlXlXxXpX#.mXjXlXhXZXC.+ I.c._.BXzXlXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXjXmX,Xi i ,XmXjXlXlXlXxXpX#.mXjXlXgXDXy.  y <   r.NXjXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXjXBX#X    #XBXjXlXlXlXxXpX#.mXjXlXkXcXqXL.%XlXZ @ qXbXkXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXkXvXeXd.d.eXvXkXlXlXlXxXpX#.mXjXlXkXcX;X*XNXUXy.  ,XMXjXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXkXcXHXHXcXkXlXlXlXlXxXpX#.mXjXlXgXFX<.  B.=X8 w dXxXkXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXkXgXgXkXlXlXlXlXlXxXpX#.mXjXlXkXcXqXZ     > !.NXjXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXkXnXkX`.R.9XNXkXlXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXkXlXCXSXvXjXlXlXlXlXgXJX@.  O     ",
"  .   w q.  O                             O   d.GXgXlXlXlXlXlXlXlXlXlXlXlXlXlXxXpX#.mXjXlXlXlXlXkXhXhXkXlXlXlXlXlXgXJX@.  O     ",
"  .   q 9.  O                             O   a.AXpXgXgXgXgXgXgXgXgXgXgXgXgXfXjXtX+.xXdXgXgXgXgXgXgXgXgXgXgXgXgXgXpXSXO.  O     ",
"  .   r s.  O                             +   n.UXSXJXJXJXJXJXJXJXJXJXJXJXJXHXLXBX>.UXGXJXJXJXJXJXJXJXJXJXJXJXJXJXSXUX;.  O     ",
"      - b   X                             X   B -.O.@.@.@.@.@.@.@.@.@.@.@.@.@.#.X.g %.+.@.@.@.@.@.@.@.@.@.@.@.@.@.O.;.f   X     ",
"    .     .                                 X                                                                           .       ",
"      . X                                     X O O O O O O O O O O O O O O O O O X O O O O O O O O O O O O O O O O O X         ",
"                                                                                                                                ",
"                                                                                                                                "
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"                                                                                                ",
"      . o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o X         ",
"    .                                                                                           ",
"  .   , D v n n n n n n n n n n n Z b n n n n n n n n n n b Z n n n n n n n n n n n m n X       ",
"  X   s e.K.F.G.G.G.G.G.G.G.G.H.D.1.K.G.G.G.G.G.G.G.G.G.G.K.1.D.H.G.G.G.G.G.G.G.G.D.E...  X     ",
"  o   m H.DXbXMXMXMXMXMXMXMXMXNXxXj.ZXnXMXmXnXbXbXbXmXMXnXZXj.xXNXMXMXMXMXMXMXMXMXcXUX2.  +     ",
"  o   b F.bXfXhXhXhXhXhXhXhXhXkXaXh.xXgXhXjXNXVXBXMXjXhXgXxXh.aXkXhXhXhXhXhXhXhXhXsXSX1.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXzXgX'.!./.oXgXzXkXbXj.fXzXlXlXlXjXjXlXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXjXcXyXZ s 7 & wXvXjXbXj.fXzXlXlXlXMXmXkXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXlXlXjXHX| P ZXjXkXbXj.fXzXlXlXlX;X1XxXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXlXjXmX<X& oXVXjXkXbXj.fXzXkXzXxX  u SXhXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXlXgXKX] K FXhXlXkXbXj.fXzXlXlXzXu.n.mXkXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXjXNXOX  +XNXjXlXkXbXj.fXzXlXlXlXFXAXkXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXjXBXE.p.MXkXlXlXkXbXj.fXzXlXlXlXgXhXlXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXlXjXNXSXkXlXlXlXkXbXj.fXzXlXlXlXlXlXlXlXlXgXGX2.  O     ",
"  o   n H.NXkXzXzXzXzXzXzXzXzXcXgXk.nXlXzXxXlXjXzXzXzXzXlXnXk.gXcXzXzXzXzXzXzXzXzXhXJX3.  O     ",
"  o   b S.xXaXfXfXfXfXfXfXfXfXgXuXf.kXsXfXfXfXfXfXfXfXfXsXkXf.uXgXfXfXfXfXfXfXfXfXiXCX,.  O     ",
"  X   e  .c.h.j.j.j.j.j.j.j.j.k.f.^ z.h.j.j.j.j.j.j.j.j.h.z.^ f.k.j.j.j.j.j.j.j.j.g.N.J   X     ",
"  o   m K.CXxXbXbXbXbXbXbXbXbXnXkXz.NXcXbXbXbXbXbXbXbXbXcXNXz.kXnXbXbXbXbXbXbXbXbXlXPX4.  O     ",
"  o   b G.nXgXkXkXkXkXkXkXkXkXlXsXh.cXjXkXkXkXkXkXkXkXkXjXcXh.sXlXkXkXkXkXkXkXkXkXfXFX1.  O     ",
"  o   n G.MXhXlXlXlXkXkXlXlXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXlXkXkXlXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXzXbXxXlXlXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXlXvXvXlXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXzXjXeXsXzXlXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXlXyXiXzXlXlXgXGX2.  O     ",
"  o   n G.MXhXjXNX&X  6.HXgXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXzXxX* z AXhXlXgXGX2.  O     ",
"  o   n G.MXhXkXnX6XU L.CXhXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXzXO.8.NXjXlXgXGX2.  O     ",
"  o   n G.MXhXlXkXcXJXNXkXlXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXlXFXAXkXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXkXgXjXlXlXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXlXgXhXlXlXlXgXGX2.  O     ",
"  o   n G.MXhXlXlXlXlXlXlXlXlXzXfXj.bXkXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXlXlXlXlXlXlXgXGX2.  O     ",
"  o   n D.vXdXgXgXgXgXgXgXgXgXjXpXh.vXjXkXkXkXkXkXkXkXkXjXcXh.sXlXkXkXkXkXkXkXkXkXfXFX1.  O     ",
"  o   n T.UXAXDXDXDXDXDXDXDXDXGXVXv.NXvXbXbXbXbXbXbXbXbXcXNXz.kXnXbXbXbXbXbXbXbXbXlXPX4.  O     ",
"  X   u J ( / ( ( ( ( ( ( ( ( ) W L v.h.j.j.j.j.j.j.j.j.h.z.^ f.k.j.j.j.j.j.j.j.j.g.N.J   X     ",
"  o   P i                         W VXpXfXfXfXfXfXfXfXfXsXkXf.uXgXdXfXdXdXdXdXfXfXiXCX,.  O     ",
"  o   I l   + O O O O O O O O #   ) GXjXzXzXzXzXzXzXzXzXlXnXk.gXcXzXzXcXvXbXcXzXzXhXJX3.  O     ",
"  o   I j   X                 O   ( DXgXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXgXuXtXsXzXlXgXGX2.  O     ",
"  o   I j   X                 O   ( DXgXlXlXlXzXlXlXlXlXkXbXj.fXzXlXlXD i a -.BXjXgXGX2.  O     ",
"  o   I j   X                 O   ( DXgXlXlXlXxXzXlXlXlXkXbXj.fXlXvXeX6 <.d.6XvXkXgXGX2.  O     ",
"  o   I j   X                 O   ( DXgXkXvXyX* O.FXgXlXkXbXj.fXlXvXwXz ~ w %.BXjXgXGX2.  O     ",
"  o   I j   X                 O   ( DXgXkXvXiXz 8.AXhXlXkXbXj.fXzXzXdX1XUX|.% dXcXfXGX2.  O     ",
"  o   I j   X                 O   ( DXgXlXlXzXAXNXkXlXlXkXbXj.fXlXnX4X8 m.[ k nXlXfXGX2.  O     ",
"  o   I j   X                 O   ( DXgXlXlXlXhXjXlXlXlXkXbXj.fXzXkXnXB.l H =XmXjXgXGX2.  O     ",
"  o   I j   X                 O   ( DXgXlXlXlXlXlXlXlXlXkXbXj.fXzXlXlXCXVXZXnXkXlXgXGX2.  O     ",
"  o   P j   X                 O   / CXaXgXgXgXgXgXgXgXgXfXlXg.iXhXgXgXsXdXdXdXgXgXaXAX<.  O     ",
"  o   E x   X                 O   { UXAXGXGXGXGXGXGXGXGXFXPXN.CXJXGXGXGXGXGXGXGXGXAXUXq.  +     ",
"  .   y 4   .                 X   d 0.<.2.2.2.2.2.2.2.2.1.4.J ,.3.2.2.2.2.2.2.2.2.<.q.N   X     ",
"    .     .                     .                                                       .       ",
"      . .                         . O O O O O O O O O O O O X O O O O O O O O O O O + X         ",
"                                                                                                ",
"                                                                                                "
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"                                                                                        ",
"      . o X o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o o X         ",
"    .                                                                                   ",
"  .   > B k z z z z z z z z l v b l z z z z z z z z l b v l z z z z z z z z z x o       ",
"  X   a h.^.E.W.W.W.W.W.W.E.(.n.g.).E.W.W.W.W.W.W.E.).g.n.(.E.W.W.W.W.W.W.R.].>.  X     ",
"  o   x ~.FXbXMXMXMXMXMXMXnXHX%X/.LXbXMXbXvXvXbXMXbXLX/.%XHXnXMXMXMXMXMXMXvXUXs.  O     ",
"  o   l E.bXfXhXhXhXhXhXhXgXmXXXE.BXfXhXCXFXDXVXhXfXBXE.XXmXgXhXhXhXhXhXhXdXSXp.  O     ",
"  o   z W.MXhXlXlXlXlXlXlXjXBXOXQ.CXhXcX8.T ) q.zXhXCXQ.OXBXjXlXlXjXkXlXlXgXFXa.  O     ",
"  o   z W.MXhXlXlXlXlXlXlXjXBXOXQ.CXhXxXJ.B.n m ZXfXCXQ.OXBXkXlXzXSXbXkXlXgXFXa.  O     ",
"  o   z W.MXhXlXlXlXlXlXlXjXBXOXQ.CXjXkXAXSXj /.ZXfXCXQ.OXBXhXnX8Xr H.AXhXgXFXa.  O     ",
"  o   z W.MXhXlXlXlXlXlXlXjXBXOXQ.CXjXgXHXt.N SXjXhXCXQ.OXBXhXbX9Xd P.ZXhXgXFXa.  O     ",
"  o   z W.MXhXlXlXlXlXlXlXjXBXOXQ.CXgXvXrX1 (.CXjXjXCXQ.OXBXkXlXxXFXnXkXlXgXFXa.  O     ",
"  o   z W.MXhXlXlXlXlXlXlXjXBXOXQ.CXgXNX X0.nXkXlXjXCXQ.OXBXjXlXlXhXkXlXlXgXFXa.  O     ",
"  o   l E.mXgXjXjXjXjXjXjXhXMXoXW.VXgXhXvXAXhXjXjXgXVXW.oXMXhXjXjXjXjXjXjXfXDXp.  O     ",
"  o   c ).GXmXBXBXBXBXBXBXMXJX=X_.PXmXBXNXmXBXBXBXmXPX_.=XJXMXBXBXBXBXBXBXnXUXh.  O     ",
"  X   a k.*XXXOXOXOXOXOXOXoX=XS.l.;XXXOXOXOXOXOXOXXX;Xl.S.=XoXOXOXOXOXOXOX.X<X;.  o     ",
"  X   y e.).E.Q.Q.Q.Q.Q.Q.W._.l.r.'.E.Q.Q.Q.Q.Q.Q.E.'.r.l._.W.Q.Q.Q.Q.Q.Q.R.}.o.  o     ",
"  o   c `.KXBXCXCXCXCXCXCXVXPX;X'.UXBXCXCXCXCXCXCXBXUX'.;XPXVXCXCXCXCXCXCXMXUXk.  O     ",
"  X   l R.nXfXjXjXhXhXjXjXgXmXXXE.BXfXjXjXjXjXjXjXfXBXE.XXmXgXjXhXhXhXjXjXdXSXi.  O     ",
"  o   z W.MXhXlXlXzXzXlXlXjXBXOXQ.CXjXlXlXlXlXlXlXjXCXQ.OXBXjXlXlXxXzXlXlXgXFXa.  O     ",
"  o   z W.MXhXlXlXlXlXlXlXjXBXOXQ.CXjXlXlXlXlXlXlXjXCXQ.OXBXjXlXlXlXlXlXlXgXFXa.  O     ",
"  o   z W.MXhXjXZXv C SXhXjXBXOXQ.CXjXlXlXlXlXlXlXjXCXQ.OXBXhXmX4X  n.DXgXgXFXa.  O     ",
"  o   z W.MXhXkXMXq.y.NXjXjXBXOXQ.CXjXlXlXlXlXlXlXjXCXQ.OXBXjXvXrX] '.BXjXgXFXa.  O     ",
"  o   z W.MXhXlXkXDXSXkXlXjXBXOXQ.CXjXlXlXlXlXlXlXjXCXQ.OXBXkXkXxXJXmXkXlXgXFXa.  O     ",
"  o   z W.MXhXlXlXhXhXlXlXjXBXOXQ.CXjXlXlXlXlXlXlXjXCXQ.OXBXjXlXlXgXjXlXlXgXFXa.  O     ",
"  X   l R.bXfXhXhXhXhXhXhXgXmX.XE.BXfXjXjXjXjXjXjXfXBXE.XXmXgXjXjXjXjXjXjXdXSXi.  O     ",
"  o   c '.LXVXZXZXZXZXZXZXCXIX:X'.UXBXCXCXCXCXCXCXBXUX'.;XPXVXCXCXCXCXCXCXMXUXk.  O     ",
"  X   y e.(.R.W.W.W.W.W.W.E.).k.r.'.E.Q.Q.Q.Q.Q.Q.E.'.r.l._.W.Q.Q.Q.Q.Q.Q.R.}.o.  o     ",
"  X   M 6                       k.:X.XOXOXOXOXOXOXXX;Xl.S.=XoXOXoXoXoXOXOX.X<X;.  o     ",
"  o   K f   O o o o o o o o @   ).IXmXBXBXBXBXBXBXmXPX_.=XJXMXBXCXZXZXVXBXnXUXh.  O     ",
"  o   G a   .               o   E.CXgXjXjXhXjXkXjXgXVXW.oXMXhXkXsXqXwXgXkXdXDXp.  O     ",
"  o   G a   .               o   W.ZXhXlXlXmXvXkXlXjXCXQ.OXNXzXiXm Z Z @XMXdXFXa.  O     ",
"  o   G a   .               o   W.ZXhXlXlX4XrXxXlXjXCXQ.OXMXnX*X, #.g.xXlXgXFXa.  O     ",
"  o   G a   .               o   W.ZXgXxXlX  ] JXgXjXCXQ.OXNXxX0X&.y.e K.ZXsXFXa.  O     ",
"  o   G a   .               o   W.ZXhXzXlXn.'.mXjXjXCXQ.OXNXvX4XL.UXW *.LXaXFXa.  O     ",
"  o   G a   .               o   W.ZXhXlXlXDXBXkXlXjXCXQ.OXNXcX8Xi b a &XmXdXFXa.  O     ",
"  o   G a   .               o   W.ZXhXlXlXgXjXlXlXjXCXQ.OXBXhXmXpXI.7XMXjXgXFXa.  O     ",
"  X   F a   .               o   T.NXsXgXgXgXgXgXgXdXMXR..XnXfXfXkXVXzXdXgXaXZXi.  O     ",
"  o   P f   .               o   [.UXAXFXFXFXFXFXFXSXUX}.<XUXDXFXDXSXDXFXFXZXUXx.  O     ",
"  .   i 4   .               X   o.k.i.a.a.a.a.a.a.i.k.o.;.h.p.a.a.a.a.a.a.i.x.T   X     ",
"    .     .                   .                                                 .       ",
"      . .                       o O O O O O O O O O O o o O O O O O O O O O O X         ",
"                                                                                        ",
"                                                                                        "
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"                                                                ",
"  . ; & & & & & & & & : & & & & & & & & : * & & & & & & & - o   ",
"  $ 4.F.C.Z.Z.Z.Z.C.A.e.V.Z.C.V.V.C.C.D.t.n.A.Z.Z.Z.Z.V.H.0.    ",
"  & S.SXbXmXmXmXmXnXVXE.cXMXBXJXGXCXbXDX^.pXVXmXmXmXmXvXLXE.  o ",
"  & C.bXgXjXjXjXjXhXxXY.sXxXrX^.[.6XjXnXQ.wXxXjXhXgXjXfXCXY.  o ",
"  & Z.mXjXlXlXlXlXkXcXT.dXMX=X=.d <.DXbXQ.eXvXjXMXZXkXhXAXY.  o ",
"  & Z.mXjXlXlXlXlXkXcXT.gXlXcXKXE @XmXmXQ.eXzXSXv.[ ZXfXAXY.  o ",
"  & Z.mXjXlXlXlXlXkXcXT.gXjXDXk.[ HXfXMXQ.eXxXNX_.v.MXgXAXY.  o ",
"  & Z.mXjXlXlXlXlXkXcXT.gXlXbX..&XMXhXMXQ.eXvXjXBXDXkXhXAXY.  o ",
"  & C.nXhXkXkXkXkXjXcXY.fXzXhXlXcXjXhXmXQ.wXcXkXhXgXkXgXZXY.  o ",
"  & S.VXxXcXcXcXcXcXmXE.kXbXvXvXcXvXxXCX^.yXmXcXcXcXcXlXFXE.  o ",
"  # >.!.U.T.T.T.T.Y.E.8.I.T.T.Y.T.T.U.~.q.D.E.Y.T.T.T.U.(.8.  X ",
"  & B.cXdXgXgXgXgXfXkXI.aXhXgXgXgXgXdXvXR.9XkXfXgXgXgXsXNXP.  o ",
"  & Z.MXkXzXjXkXzXlXbXT.hXxXzXzXzXzXkXNX!.rXbXzXkXjXzXjXSXT.  o ",
"  & Z.mXjXjXDXBXjXkXcXT.gXzXlXlXlXlXjXMXQ.eXvXjXBXDXjXhXAXY.  o ",
"  & Z.mXgXVX3.J.ZXhXcXT.gXzXlXlXlXlXjXMXQ.eXzXCXJ.3.VXfXAXY.  o ",
"  & Z.mXgXVX3.J.ZXhXcXT.gXzXlXlXlXlXjXMXQ.eXzXCXJ.3.VXfXAXY.  o ",
"  & Z.mXjXkXDXBXjXkXcXT.gXzXlXlXlXlXjXMXQ.eXvXjXBXDXkXhXAXY.  o ",
"  & V.cXdXgXsXdXhXfXkXU.dXkXjXjXjXjXgXnXW.qXxXjXgXfXjXfXCXU.  o ",
"  & L.UXSXFXFXFXFXDXKX(.cXNXMXMXMXMXnXDX).sXCXMXMXMXMXbXLX!.  o ",
"  & o.g.s.d.d.d.d.d.s.-.Q.!.Q.Q.Q.Q.W.).t.K.^.Q.Q.Q.Q.E.].q.  X ",
"  8 f                 N jX0XeXeXeXeXqXsXK.,XuXeXrXtXrX0XjXD.  o ",
"  9 M   @ O O O O #   P DXzXvXzXzXvXxXCX^.uXmXbXxXsXlXzXFXE.  o ",
"  9 n   X         o   J CXhXjXCXCXjXjXMXQ.qXBX:XG '  XbXVXY.  o ",
"  9 n   X         o   J ZXfXBXJ.J.BXgXMXQ.qXSX`.j ] &XvXCXY.  o ",
"  9 n   X         o   J ZXdXDX3.3.DXfXMXQ.wXNX:X&Xd.} FXBXY.  o ",
"  9 n   X         o   J ZXjXjXVXVXkXjXMXQ.wXCX#XW Y G.NXVXY.  o ",
"  8 b   X         o   H NXdXhXfXfXhXfXbXE.0XkXcX;X+XbXsXBXI.  o ",
"  0 N   X         o   I UXVXAXAXAXAXCXLX].jXGXCXJXLXCXVXUX(.  o ",
"  1 p   .         X   z /.I.Y.Y.Y.Y.U.!.q.D.E.Y.U.U.Y.I.(.7.  X ",
"      .             .                                       .   ",
"    .                 . o o o o o o o o X o o o o o o o o X     "
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"o 1 > > > > > > 2 > > > > > > 2 , > > > > > < + ",
": b. X_.'.'.'.`.m.'.'.[.'._.}.B.Q.[.`.`._. XA.O ",
"> |.HXmXNXNXNXNX|.BXNXlXMXNXDX+XfXZXMXmXmXHX-X  ",
"> _.mXgXjXjXjXhX_.lXuXw.H }.AX[.eXlXxXMXfXmX+X  ",
"> '.NXjXlXlXlXlX'.lXcXdX` tXBX}.eXAX|.>.NXMX@X  ",
"> '.NXjXlXlXlXlX'.jXDXp.v.FXcX|.rXmX0X|.xXNX#X  ",
"> '.NXjXlXlXlXlX'.lXcX{.sXlXmX|.tXcXvXBXhXBX#X  ",
"> `.NXhXlXlXlXkX`.lXkXNXzXjXnX|.rXcXkXjXjXNX@X  ",
"- k..X_.'.'.'.`.k.'.'._.`.`.|.c.W.[.'.'._..XN.  ",
"> '.BXkXjXkXzXlX'.zXlXlXlXkXmX|.tXvXkXjXkXBX#X  ",
"> `.NXgXSXnXkXlX'.lXlXlXlXjXmX|.tXxXbXSXhXBX@X  ",
"> `.MXbXv.=XMXjX'.lXlXlXlXjXmX|.rXVX=Xv.nXMX@X  ",
"> `.MXbXv.=XMXjX'.lXlXlXlXjXmX|.rXVX=Xv.nXMX@X  ",
"> ).nXsXCXxXfXgX_.kXjXjXjXhXbX}.rXlXvXAXfXMX+X  ",
"> OXUXAXZXSXDXDXXXmXmXmXmXbXAXOXsXBXbXvXbXDX=X  ",
"> 6.B.v.b.b.n.x.y.XX}.|.|.}.OXm.^.XX[.[.{.#XZ.  ",
"r 3             ^ cXqXrXrXrXsX^.3XuXhXzXyXfX[.  ",
"t u   + O O #   X.JXjXVXVXlXBX.XuXBX].H.tXDX%X  ",
"t r   .     O   | SXxX=X=XvXbX}.rXnXK I 6XAX+X  ",
"t r   .     O   | ZXVXv.v.AXvX|.yXhXQ.3.b.UXoX  ",
"r r   .     O   } AXsXnXnXfXbX{.wXbXd.X.&XAXOX  ",
"y y   .     O   o.UXnXMXMXMXDX@XfXAXCXNXAXGX:X  ",
"9 9   .     o   E 2XoX@X@X+X=XZ.[.%X+X@XOX:XJ.  ",
"                                                "
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
". @ + + + # @ O o @ # + + + @ . ",
"+ V.@X{.XXU.).OX%X[.P..X|.#XA.. ",
"+ @XJXnXSX7XvX%XS.MX3XZXlXHX=X  ",
"+ {.nXdXzX;XgX|.l.cX%XxXH.lXoX  ",
"+ oXAXzXNX3XlX2XsXvX<XMXvXSX$X  ",
"+ P.8X-X4X`.$X7X3X-X(.2X-X8XT.  ",
"+ ).lXfXdX%X8XpXiXeX+XaXgXlX].  ",
"+ XXMXoXMX2XaXbXcXjX>XmXoXMX#X  ",
"+ }.cX}.cX>XpXcXxXgX:XbXXXmX@X  ",
"O #XPXFXFX7XwXjXgXpX&XjXkXbX X  ",
"= J K J F / =X:X:X&X!.1X5X6XI.  ",
"1 ;       w bXvXbXjX2XsXC.vX%X  ",
"< 6   @   s mX.X.XlX>X5XQ $X*X  ",
"1 6   o   d CXnXmXbX7XnXL.gX,X  ",
": 1   X   r +X+X@X XI.$X&X>XS.  ",
"                                "
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
